python_sureshmnv
================

.. image:: https://img.shields.io/pypi/v/python_sureshmnv.svg
    :target: https://pypi.python.org/pypi/python_sureshmnv
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/sureshmnv/python_mnv_pkg.png
   :target: https://travis-ci.org/sureshmnv/python_mnv_pkg
   :alt: Latest Travis CI build status

Additional wrappers for basic python installation

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`python_sureshmnv` was written by `Suresh Melam <sureshmnv@yahoo.com>`_.
